pitchtools.diatonic_pitch_number_to_diatonic_pitch_class_number
===============================================================

.. autofunction:: abjad.tools.pitchtools.diatonic_pitch_number_to_diatonic_pitch_class_number.diatonic_pitch_number_to_diatonic_pitch_class_number
